==> haskell-persistent-2.14.5.1-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent
version:              2.14.5.1
visibility:           public
id:                   persistent-2.14.5.1-A7PDWxshjt62iLTQn703Ca
key:                  persistent-2.14.5.1-A7PDWxshjt62iLTQn703Ca
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  01d291b980bae6a105205d764a3e16e8
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.5.1-A7PDWxshjt62iLTQn703Ca
depends:
    aeson-2.1.2.1-JD8QPsoBF4NC1qVY6ch6us
    attoparsec-0.14.4-LYMz7sGPlLCLdIXUlDCVP9 base-4.17.2.1
    base64-bytestring-1.2.1.0-3xTWh9pwP9a781vByOHbcb
    blaze-html-0.9.2.0-DBNekIonl9ZHQcEIbEIyEL bytestring-0.11.5.3
    conduit-1.3.6.1-5zFQSWi5xEVBAmxL35th12 containers-0.6.7
    deepseq-1.4.8.0 fast-logger-3.2.3-F6uFSsZg53fApTxegWjPy9
    http-api-data-0.6-ClooBVNz20NCXyLRU2W3pP
    lift-type-0.1.2.0-HH0KzK4ADsS8vZ1YzDwMYE
    monad-logger-0.3.42-GMF9gvzPow1E9lLZVRGYka mtl-2.2.2
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    resource-pool-0.2.3.2-Bf68bDyYrlPBnRhAYnhWvs
    resourcet-1.2.6-KmQzw70LfCm1KIvdRF4aq4
    scientific-0.3.8.0-JrlaAXGfnydA9ZtLsuTElg
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-50lKQ3Y2qaH31N12RxK2sY
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-7kbiIaScyuZ2eJN0OstLgA
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-ASGEyX3xTBf3ZK5sYSGlF8
    vault-0.3.1.5-1VSHZfUriLZ36tLfRqtE3c
    vector-0.13.2.0-L6HpF7nmtGm1K7R40olL6U

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.14.5.1-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent
version:              2.14.5.1
visibility:           public
id:                   persistent-2.14.5.1-5IWmPh3PFl8CnyAefmhKhl
key:                  persistent-2.14.5.1-5IWmPh3PFl8CnyAefmhKhl
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  3827d1491ab8251705c41a4e9f9688c4
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.5.1-5IWmPh3PFl8CnyAefmhKhl
depends:
    aeson-2.1.2.1-H1ahbkp4Y7o4mfa4dlXJ2M
    attoparsec-0.14.4-EuJHdCyQx9qFeM6j3QZsTf base-4.17.2.1
    base64-bytestring-1.2.1.0-Chm70B0PYm3wQkrmM5U2R
    blaze-html-0.9.2.0-9XbYd3BuaoOCWGJeBuMwxI bytestring-0.11.5.3
    conduit-1.3.6.1-Ft7mdP42es1IIbhkIhPjly containers-0.6.7
    deepseq-1.4.8.0 fast-logger-3.2.3-186ijCVkjI452jEwolL50q
    http-api-data-0.6-9xsENVRE53bLOnO101AOpS
    lift-type-0.1.2.0-LGHYiKamLsSGMlzeCLSCGt
    monad-logger-0.3.42-KddZ7zrxcI29xv9TnvX3il mtl-2.2.2
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    resource-pool-0.2.3.2-BSzNcpf447z2hIQQhjXlap
    resourcet-1.2.6-ET2VDG6LFtqBIJu0pivevH
    scientific-0.3.8.0-6uPUyX2SLNQ5uEuI9iq9EK
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-1ltNaZBsRyLHsoURdEtsZi
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-7tyRVJx8ZNHIaUyarAToDA
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-L0GY6JfHBKC8QjVdSVYiO8
    vault-0.3.1.5-IMEMFFEePP0AkwAGAJ7sH7
    vector-0.13.2.0-LTUcBi4LXgv7CSERMHHzQp

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
